pub struct FrameBuilder {
segments: Vec<Option<Segment>>,
frame_id: FrameId,
seg_remaining: u8,
recv_bytes: usize,
pub(crate) last_recv: Instant,
}Expand description
A helper object that reassembles segments into frames.
Fields
segments: Vec<Option<Segment>>frame_id: FrameIdseg_remaining: u8recv_bytes: usizelast_recv: InstantImplementations
Sourceimpl FrameBuilder
impl FrameBuilder
Sourcepub fn add_segment(&mut self, segment: Segment) -> Result<(), SessionError>
pub fn add_segment(&mut self, segment: Segment) -> Result<(), SessionError>
Adds a segment to this frame.
Fails if the segment is invalid for this frame.
Sourcepub fn as_missing(&self) -> BitArray<[u8; 1], Msb0>
pub fn as_missing(&self) -> BitArray<[u8; 1], Msb0>
Retrieves the bitmap of missing segments in this frame.
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Indicates if all segments of this frame were added.